@@ -2,12 +2,11 @@
 #define GDECODE_H
 #include <stdio.h>
 #include <stdlib.h>
-#include "fortint.h"
 #include <string.h>
 #include <ctype.h>
-
+#include "common/fortint.h"
+#include "common/fortreal.h"
 #include "gdecodeStruct.h"
-
 #include "sencode1.h"
 
 #ifdef FORTRAN_NO_UNDERSCORE
@@ -146,7 +145,7 @@
 #define RGSUBID rgsubid_
 #endif
 
-#define MOVE1BYTE(p,n)  ( *(p)     = ((*(n)>> 0) & 0xFF) ) 
+#define MOVE1BYTE(p,n)  ( *(p)     = ((*(n)>> 0) & 0xFF) )
 #define MOVE2BYTES(p,n) ( *(p)     = ((*(n)>> 8) & 0xFF) ) , \
                         ( *((p)+1) = ((*(n)>> 0) & 0xFF) )
 #define MOVE3BYTES(p,n) ( *(p)     = ((*(n)>>16) & 0xFF) ) , \
